/**
    @file ft51_aio.h

    @brief     Functions to control the FT51 analogue cells.

    Read from (ADC) analogue cells.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_AIO_H__
#define __FT51_AIO_H__

#include <stdint.h>
#include "ft51.h"
#include "ft51_iomux.h"


/**
    @brief      Initialise the AIO Cell Controller.

    Reset and enable the AIO Cell Controller.  
    Call this (once) before calling any other AIO functions;
    otherwise, behaviour is undefined.
**/
void AIO_initialise(void);


/**
    @brief      Sample the specified analog pad.

    Implemented by successive approximations (in hardware) 
    to the output of a sample-and-hold circuit.
    This function will block execution until conversion is 
    complete.  Calling this function before enabling the AIO 
    Cell Controller will result in undefined behaviour.

    @param[in] pad   Specifies the analog IO pad (AIO_0 to AIO_15) to read.

    @return 8 bit quantity representing the ratio of the sampled voltage to
            the voltage at the VOUT3V3 pin (typically 3.3 volts).  
            For example, 255 represents 3.3 V, and 100 represents 1.294 V 
            (3.3 * 100/255).
**/
uint8_t AIO_read(IOMUX_PAD  pad);

#endif // __FT51_AIO_H__