/**
    @file ft51_registers.h

    @brief Registers library

    Defines top-level registers and bit-masks.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_REGISTERS_H__
#define __FT51_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 0 (0x0) DEVICE_CONTROL_REGISTER
#define DEVICE_CONTROL_REGISTER                           0x0

// Register 0 Bit Definitions
#define BIT_TOP_SOFT_RESET                    0                                 // Write a 1 to reset TOP
#define MASK_TOP_SOFT_RESET                   (0x1 << BIT_TOP_SOFT_RESET)
#define BIT_TOP_DEV_EN                        1                                 // Write a 1 to enable TOP
#define MASK_TOP_DEV_EN                       (0x1 << BIT_TOP_DEV_EN)

//------------------------------------------------------------------------------
// Register 1 (0x1) SYSTEM_CLOCK_DIVIDER
#define SYSTEM_CLOCK_DIVIDER                   0x1

// Register 1 Bit Definitions
#define BIT_HUB_SUSPEND_EN                    0                                 // Allow the hub to enter suspend mode.
#define MASK_HUB_SUSPEND_EN                   (0x1 << BIT_HUB_SUSPEND_EN)
#define BIT_CLK_SYS_DIVISOR_0                 1                                 // System clock divisor. 0 - 48MHz. 1 - 24MHz. 2 - 12 MHz.
#define MASK_CLK_SYS_DIVISOR_0                (0x1 << BIT_CLK_SYS_DIVISOR_0)
#define BIT_CLK_SYS_DIVISOR_1                 2                                 // System clock divisor. 0 - 48MHz. 1 - 24MHz. 2 - 12 MHz.
#define MASK_CLK_SYS_DIVISOR_1                (0x1 << BIT_CLK_SYS_DIVISOR_1)
#define MASK_CLK_SYS_DIVISOR                  (0x3 << BIT_CLK_SYS_DIVISOR_0)
#define BIT_SYSTEM_STOP_REQUEST               3                                 // Suspend the device when hub is inactive. For reduced power consumption a system_stop_request should be issued when the FT122 has entered suspend.
#define MASK_SYSTEM_STOP_REQUEST              (0x1 << BIT_SYSTEM_STOP_REQUEST)
#define BIT_RESET_8051                        4                                 // Reset the 8051 CPU.
#define MASK_RESET_8051                       (0x1 << BIT_RESET_8051)

//------------------------------------------------------------------------------
// Register 2 (0x2) TOP_USB_ENABLE
#define TOP_USB_ENABLE                        0x2

// Register 2 Bit Definitions
#define BIT_FT122_ENABLE                      0                                 // FT122 Enable.  0 - disabled. 1 - enabled.
#define MASK_FT122_ENABLE                     (0x1 << BIT_FT122_ENABLE)
#define BIT_HUB_ENABLE                        1                                 // Hub Enable.  0 - disabled. 1 - enabled.
#define MASK_HUB_ENABLE                       (0x1 << BIT_HUB_ENABLE)
#define BIT_HUB_EXT_LOCALPWRSRC               2                                 // Connected to hub port, EXT_LOCALPWRSRC
#define MASK_HUB_EXT_LOCALPWRSRC              (0x1 << BIT_HUB_EXT_LOCALPWRSRC)
#define BIT_HUB_STSNZDATAHSK                  3                                 // Connected to hub port, DEV_StsNzDataHsk
#define MASK_HUB_STSNZDATAHSK                 (0x1 << BIT_HUB_STSNZDATAHSK)
#define BIT_HUB_REMOTE_WAKEUP_EN              4                                 // Connected to hub port, DEV_RmtWkUpEn
#define MASK_HUB_REMOTE_WAKEUP_EN             (0x1 << BIT_HUB_REMOTE_WAKEUP_EN)
#define BIT_HUB_COMPD_DEV                     5                                 // Connected to hub port, CompdDev
#define MASK_HUB_COMPD_DEV                    (0x1 << BIT_HUB_COMPD_DEV)

//------------------------------------------------------------------------------
// Register 3 (0x3) PERIPHERAL_INT0
#define PERIPHERAL_INT0                              0x3

// Register 3 Bit Definitions
#define BIT_WATCHDOG_IRQ                      0                                 // Watchdog Interrupt
#define MASK_WATCHDOG_IRQ                     (0x1 << BIT_WATCHDOG_IRQ)
#define BIT_DMA0_IRQ                          1                                 // MA 0 Interrupt
#define MASK_DMA0_IRQ                         (0x1 << BIT_DMA0_IRQ)
#define BIT_DMA1_IRQ                          2                                 // DMA 1 Interrupt
#define MASK_DMA1_IRQ                         (0x1 << BIT_DMA1_IRQ)
#define BIT_DMA2_IRQ                          3                                 // DMA 2 Interrupt
#define MASK_DMA2_IRQ                         (0x1 << BIT_DMA2_IRQ)
#define BIT_DMA3_IRQ                          4                                 // DMA 3 Interrupt
#define MASK_DMA3_IRQ                         (0x1 << BIT_DMA3_IRQ)

//------------------------------------------------------------------------------
// Register 4 (0x4) PERIPHERAL_IEN0
#define PERIPHERAL_IEN0                              0x4

// Register 4 Bit Definitions
#define BIT_WATCHDOG_IRQ_IEN                  0                                 // Watchdog Interrupt Enable
#define MASK_WATCHDOG_IRQ_IEN                 (0x1 << BIT_WATCHDOG_IRQ_IEN)
#define BIT_DMA0_IRQ_IEN                      1                                 // DMA 0 Interrupt Enable
#define MASK_DMA0_IRQ_IEN                     (0x1 << BIT_DMA0_IRQ_IEN)
#define BIT_DMA1_IRQ_IEN                      2                                 // DMA 1 Interrupt Enable
#define MASK_DMA1_IRQ_IEN                     (0x1 << BIT_DMA1_IRQ_IEN)
#define BIT_DMA2_IRQ_IEN                      3                                 // DMA 2 Interrupt Enable
#define MASK_DMA2_IRQ_IEN                     (0x1 << BIT_DMA2_IRQ_IEN)
#define BIT_DMA3_IRQ_IEN                      4                                 // DMA 3 Interrupt Enable
#define MASK_DMA3_IRQ_IEN                     (0x1 << BIT_DMA3_IRQ_IEN)

//------------------------------------------------------------------------------
// Register 5 (0x5) PERIPHERAL_INT1
#define PERIPHERAL_INT1                            0x5

// Register 5 Bit Definitions
#define BIT_FT122_IRQ                         0                                 // USB Device (FT122) Interrupt
#define MASK_FT122_IRQ                        (0x1 << BIT_FT122_IRQ)
#define BIT_IO_CELL_CONTROLLER_IRQ            1                                 // IO Cell Controller Interrupt
#define MASK_IO_CELL_CONTROLLER_IRQ           (0x1 << BIT_IO_CELL_CONTROLLER_IRQ)
#define BIT_UART_IRQ                          2                                 // Uart Interrupt
#define MASK_UART_IRQ                         (0x1 << BIT_UART_IRQ)
#define BIT_SPI_MASTER_IRQ                    3                                 // SPI Master Interrupt
#define MASK_SPI_MASTER_IRQ                   (0x1 << BIT_SPI_MASTER_IRQ)
#define BIT_SPI_SLAVE_IRQ                     4                                 // SPI Slave Interrupt
#define MASK_SPI_SLAVE_IRQ                    (0x1 << BIT_SPI_SLAVE_IRQ)
#define BIT_PWM_IRQ                           5                                 // PWM Interrupt
#define MASK_PWM_IRQ                          (0x1 << BIT_PWM_IRQ)
#define BIT_TIMER_IRQ                         6                                 // Timer Interrupt
#define MASK_TIMER_IRQ                        (0x1 << BIT_TIMER_IRQ)
#define BIT_FIFO_245_IRQ                      7                                 // 245 FIFO Interrupt
#define MASK_FIFO_245_IRQ                     (0x1 << BIT_FIFO_245_IRQ)

//------------------------------------------------------------------------------
// Register 6 (0x6) PERIPHERAL_IEN1
#define PERIPHERAL_IEN1                            0x6

// Register 6 Bit Definitions
#define BIT_FT122_IRQ_IEN                     0                                 // USB Device (FT122) Interrupt Enable
#define MASK_FT122_IRQ_IEN                    (0x1 << BIT_FT122_IRQ_IEN)
#define BIT_IO_CELL_CONTROLLER_IRQ_IEN        1                                 // IO Cell Controller Interrupt Enable
#define MASK_IO_CELL_CONTROLLER_IRQ_IEN       (0x1 << BIT_IO_CELL_CONTROLLER_IRQ_IEN)
#define BIT_UART_IRQ_IEN                      2                                 // Uart Interrupt Enable
#define MASK_UART_IRQ_IEN                     (0x1 << BIT_UART_IRQ_IEN)
#define BIT_SPI_MASTER_IRQ_IEN                3                                 // SPI Master Interrupt Enable
#define MASK_SPI_MASTER_IRQ_IEN               (0x1 << BIT_SPI_MASTER_IRQ_IEN)
#define BIT_SPI_SLAVE_IRQ_IEN                 4                                 // SPI Slave Interrupt Enable
#define MASK_SPI_SLAVE_IRQ_IEN                (0x1 << BIT_SPI_SLAVE_IRQ_IEN)
#define BIT_PWM_IRQ_IEN                       5                                 // PWM Interrupt Enable
#define MASK_PWM_IRQ_IEN                      (0x1 << BIT_PWM_IRQ_IEN)
#define BIT_TIMER_IRQ_IEN                     6                                 // Timer Interrupt Enable
#define MASK_TIMER_IRQ_IEN                    (0x1 << BIT_TIMER_IRQ_IEN)
#define BIT_FIFO_245_IRQ_IEN                  7                                 // 245 FIFO Interrupt
#define MASK_FIFO_245_IRQ_IEN                 (0x1 << BIT_FIFO_245_IRQ_IEN)

//------------------------------------------------------------------------------
// Register 9 (0x9) PIN_CONFIG
#define PIN_CONFIG                   0x9

// Register 9 Bit Definitions
#define BIT_VBUS_DETECT_MODE                  0                                 // A pin has been connected to VBUS for VBUS detect mode.
#define MASK_VBUS_DETECT_MODE                 (0x1 << BIT_VBUS_DETECT_MODE)
#define BIT_DEBUGGER_PIN_STATE                1                                 // Read this to get the state of the debugger pin
#define MASK_DEBUGGER_PIN_STATE               (0x1 << BIT_DEBUGGER_PIN_STATE)

//------------------------------------------------------------------------------
// Register 52 (0x34) PIN_PACKAGE_CONFIG
#define PIN_PACKAGE_CONFIG                    0x34

// Register 52 Bit Definitions
#define BIT_PIN_24_32_NOT_44                  6                                 // Read as Active Low signal. Device Type - 1 = 44 pin; 0 = 24 or 32 pin. If 1, no need to look at pin_24_not_32
#define MASK_PIN_24_32_NOT_44                 (0x1 << BIT_PIN_24_32_NOT_44)
#define BIT_PIN_24_NOT_32                     7                                 // Read Active Low signal. Device Type - 1 = 32 pin; 0 = 24 pin. Only need to look at this if pin_24_32_not_44 is 0
#define MASK_PIN_24_NOT_32                    (0x1 << BIT_PIN_24_NOT_32)

#endif // __FT51_REGISTERS_H__
